@@ -4,13 +4,7 @@ from __future__ import annotations
 
 import typing
 
-from hsc_instructions.arg_types import (
-    Label,
-    PointerDeref,
-    Register,
-    Shift,
-    ShiftType,
-)
+from hsc_instructions.arg_types import Label, PointerDeref, Register, Shift, ShiftType
 from hsc_instructions.errors import ParseError, format_error
 from hsc_instructions.instruction import Instruction
 from hsc_instructions.instruction_info import Instruction as InstructionEnum
