@@ -5,6 +5,7 @@ import typing as tp
 
 from hsc_instructions.errors import AsmException
 from hsc_instructions.instruction import encode_instructions
+from hsc_instructions.utilities import exit_open
 
 from hsc_assembler.asm_parser import parse
 from hsc_assembler.scanner import scan
@@ -26,9 +27,9 @@ def assemble(assembly_code: str) -> bytes:  # type: ignore
 
 
 def assemble_file(source: Path, destination: Path) -> None:
-    with open(source) as source_file:
+    with exit_open(source) as source_file:
         machine_code = assemble(source_file.read())
-    with open(destination, "wb") as destination_file:
+    with exit_open(destination, "wb") as destination_file:
         destination_file.write(machine_code)
 
 
